## Tushare数据索引

 股票基础

 分钟行情 日线行情 周线行情 月线行情 复权行情 复权因子 每日涨跌停价格 每日涨跌停统计 停复牌 交易日历

 总市值 流通市值 总股本 流通股本 自由流通股本 换手率 量比 股息率 市盈率（PE） 市净率 市销率 均线 

 上市公司基本信息 公司高管 管理层持股 新股发行 沪港通成分股 深港通成分股 历史曾用名

 财务数据

 利润表 资产负债表 现金流量表 业绩快报 业绩预告 主营业务构成 分红送股 财务审计报告 财报预披露日期表